import { defineComponent, toRef, computed, openBlock, createElementBlock, normalizeClass, unref, renderSlot } from "vue";
import useBreakpoints, { breakpointProps } from "../../composables/useBreakpoints/index.js";
import { colProp } from "../../composables/useCol/index.js";
import useClasses from "../../composables/useClasses/index.js";
import useStringTemplate from "../../composables/useStringTemplate/index.js";
const propsCol = breakpointProps(colProp), propsOffset = breakpointProps(colProp, "offset-{0}"), propsOrder = breakpointProps(colProp, "order-{0}"), _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "Col",
  props: {
    /**
     * The amount of cols the column should span. Results in: `.col-*`
     */
    cols: colProp,
    ...propsCol,
    /**
     * The amount of cols the column should be offset. Results in `.offset-*`
     */
    offset: colProp,
    ...propsOffset,
    /**
     * The position in order of the column. Results in `.order-*`
     */
    order: colProp,
    ...propsOrder
  },
  setup(__props) {
    const props = __props, colProps = {
      sm: toRef(props, "sm"),
      md: toRef(props, "md"),
      lg: toRef(props, "lg"),
      xl: toRef(props, "xl"),
      xxl: toRef(props, "xxl")
    }, colClass = computed(() => props.cols ? useStringTemplate("col-{0}", props.cols).templatedString.value : "col"), colClasses = computed(() => useBreakpoints(colProps, "col-{0}-{1}").breakpointClasses.value.map((c) => c.replace(/\-$/, ""))), offsetProps = {
      sm: toRef(props, "offsetSm"),
      md: toRef(props, "offsetMd"),
      lg: toRef(props, "offsetLg"),
      xl: toRef(props, "offsetXl"),
      xxl: toRef(props, "offsetXxl")
    }, offsetClass = computed(() => useStringTemplate("offset-{0}", props.offset).templatedString.value), offsetClasses = useBreakpoints(offsetProps, "offset-{0}-{1}").breakpointClasses, orderProps = {
      sm: toRef(props, "orderSm"),
      md: toRef(props, "orderMd"),
      lg: toRef(props, "orderLg"),
      xl: toRef(props, "orderXl"),
      xxl: toRef(props, "orderXxl")
    }, orderClass = computed(() => useStringTemplate("order-{0}", props.order).templatedString.value), orderClasses = useBreakpoints(orderProps, "order-{0}-{1}").breakpointClasses, { classes } = useClasses(computed(() => [
      colClass.value,
      ...colClasses.value,
      offsetClass.value,
      ...offsetClasses.value,
      orderClass.value,
      ...orderClasses.value
    ]));
    return (_ctx, _cache) => (openBlock(), createElementBlock("div", {
      class: normalizeClass(unref(classes))
    }, [
      renderSlot(_ctx.$slots, "default")
    ], 2));
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=Col.vue.js.map
