import { defineComponent, computed, openBlock, createElementBlock, normalizeClass, withDirectives, createElementVNode, vModelDynamic, renderSlot, createTextVNode, toDisplayString, createCommentVNode } from "vue";
import { disabledProps } from "../../composables/useDisabled/index.js";
import { idProps } from "../../composables/useId/index.js";
import { typeProp } from "./type.js";
const _hoisted_1 = ["id", "disabled", "name", "type", "value"], _hoisted_2 = ["for"], _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "FormCheck",
  props: {
    ...disabledProps,
    ...idProps,
    /**
     * Adds the `form-check-inline` class
     */
    inline: {
      type: Boolean,
      default: !1
    },
    /**
     * The classes that will be forwarded to the input
     */
    inputClass: {
      type: [String, Array, Object],
      default: void 0
    },
    /**
     * The label to display
     */
    label: {
      type: String,
      default: void 0
    },
    /**
     * The model value
     */
    modelValue: {
      type: [Boolean, String, Number],
      default: !1
    },
    /**
     * The name of the input
     */
    name: {
      type: String,
      default: void 0
    },
    /**
     * Display the check as a switch by adding the `form-switch` class
     */
    switch: {
      type: Boolean,
      default: !1
    },
    /**
     * The type of the input
     * @values 'checkbox'|'radio'
     */
    type: typeProp,
    /**
     * The value of the input
     */
    value: {
      type: [String, Number],
      default: void 0
    }
  },
  emits: [
    /**
     * Fired when the model value is updated
     * @param {any} value The new value
     */
    "update:modelValue"
  ],
  setup(__props, { emit: __emit }) {
    const props = __props, emit = __emit, checked = computed({
      get: () => props.modelValue,
      set(v) {
        let value = v;
        props.value && (value = v ? props.value : void 0), emit("update:modelValue", value);
      }
    }), isSwitch = computed(() => props.switch);
    return (_ctx, _cache) => (openBlock(), createElementBlock("div", {
      class: normalizeClass(["form-check", { "form-switch": isSwitch.value, "form-check-inline": __props.inline }])
    }, [
      withDirectives(createElementVNode("input", {
        id: _ctx.id,
        "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => checked.value = $event),
        class: normalizeClass(["form-check-input", __props.inputClass]),
        disabled: _ctx.disabled,
        name: __props.name,
        type: __props.type,
        value: __props.value
      }, null, 10, _hoisted_1), [
        [vModelDynamic, checked.value]
      ]),
      _ctx.$slots.default || __props.label ? (openBlock(), createElementBlock("label", {
        key: 0,
        class: "form-check-label",
        for: _ctx.id
      }, [
        renderSlot(_ctx.$slots, "default", {}, () => [
          createTextVNode(toDisplayString(__props.label), 1)
        ])
      ], 8, _hoisted_2)) : createCommentVNode("", !0)
    ], 2));
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=FormCheck.vue.js.map
