import { defineComponent, computed, openBlock, createBlock, unref, mergeProps, withCtx, renderSlot, createElementVNode, normalizeClass, normalizeProps, guardReactiveProps, createTextVNode, toDisplayString, createVNode, createCommentVNode } from "vue";
import useFormSelect, { formSelectProps } from "../../composables/useFormSelect/index.js";
import _sfc_main$1 from "../Dropdown/Dropdown.vue.js";
import _sfc_main$2 from "../DropdownMenuItem/DropdownMenuItem.vue.js";
import { dropdownProps } from "../../composables/useDropdown/index.js";
import extractKeysFrom from "../../library/extractKeysFrom/index.js";
import useClasses from "../../composables/useClasses/index.js";
const { disabled: disabledProp, size: sizeProp } = formSelectProps, _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "FormDropdown",
  props: {
    ...dropdownProps,
    /**
     * Disables the component
     */
    disabled: disabledProp,
    /**
     * The key that is used to get the label from a given item
     */
    labelKey: {
      type: String,
      default: "label"
    },
    /**
     * The classes that will be forwarded to the menu
     */
    menuClass: {
      type: String,
      default: "w-100"
    },
    /**
     * The model value
     */
    modelValue: {
      type: Object,
      default: void 0
    },
    /**
     * The placeholder of the dropdown
     */
    placeholder: {
      type: String,
      default: "Select"
    },
    size: sizeProp,
    /**
     * The classes that will be forwarded to the toggle
     */
    toggleClass: {
      type: String,
      default: void 0
    }
  },
  emits: [
    /**
     * Fired when the model value is updated
     * @param {any} value The new value
     */
    "update:modelValue"
  ],
  setup(__props, { emit: __emit }) {
    const props = __props, emit = __emit, propsDropdown = extractKeysFrom(Object.keys(dropdownProps), props), label = computed(() => props.modelValue ? props.modelValue[props.labelKey] : props.placeholder), { classes } = useClasses(computed(() => [
      ...useFormSelect(props).classes.value,
      props.toggleClass
    ]));
    return (_ctx, _cache) => (openBlock(), createBlock(unref(_sfc_main$1), mergeProps({ class: "form-dropdown" }, unref(propsDropdown), {
      "onClick:item": _cache[0] || (_cache[0] = ($event) => emit("update:modelValue", $event))
    }), {
      dropdownToggle: withCtx(() => [
        renderSlot(_ctx.$slots, "dropdownToggle", {}, () => [
          createElementVNode("div", {
            class: normalizeClass(["form-select", unref(classes)]),
            "data-bs-toggle": "dropdown"
          }, [
            renderSlot(_ctx.$slots, "dropdownToggleLabel", normalizeProps(guardReactiveProps({ label: label.value, modelValue: __props.modelValue })), () => [
              createTextVNode(toDisplayString(label.value), 1)
            ])
          ], 2)
        ])
      ]),
      prepend: withCtx(() => [
        _ctx.items.length === 0 ? renderSlot(_ctx.$slots, "noOptions", { key: 0 }, () => [
          createVNode(unref(_sfc_main$2), {
            class: "pe-none",
            label: "No options"
          })
        ]) : createCommentVNode("", !0),
        renderSlot(_ctx.$slots, "prepend")
      ]),
      items: withCtx((slotScope) => [
        renderSlot(_ctx.$slots, "items", normalizeProps(guardReactiveProps(slotScope)))
      ]),
      item: withCtx((slotScope) => [
        renderSlot(_ctx.$slots, "item", normalizeProps(guardReactiveProps(slotScope)))
      ]),
      append: withCtx((slotScope) => [
        renderSlot(_ctx.$slots, "append", normalizeProps(guardReactiveProps(slotScope)))
      ]),
      _: 3
    }, 16));
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=FormDropdown.vue.js.map
