import { defineComponent, computed, ref, onMounted, watch, openBlock, createBlock, unref, mergeProps, withCtx, renderSlot, createVNode, normalizeProps, guardReactiveProps } from "vue";
import _sfc_main$2 from "../FormControl/FormControl.vue.js";
import _sfc_main$1 from "../FormDropdown/FormDropdown.vue.js";
import { dropdownProps } from "../../composables/useDropdown/index.js";
import extractKeysFrom from "../../library/extractKeysFrom/index.js";
import { formControlProps } from "../../composables/useFormControl/index.js";
import useBootstrapInstance from "../../composables/useBootstrapInstance/index.js";
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "FormDropdownSearch",
  props: {
    ...formControlProps,
    /**
     * Automatically search through the items
     */
    autoSearch: {
      type: Boolean,
      default: !0
    },
    /**
     * The items of the dropdown menu
     */
    items: {
      type: Array,
      default: () => []
    },
    /**
     * The key that is used to get the label from a given item
     */
    labelKey: {
      type: String,
      default: "label"
    },
    /**
     * The model value
     */
    modelValue: {
      type: Object,
      default: void 0
    },
    /**
     * The placeholder of the form input
     */
    placeholder: {
      type: String,
      default: ""
    },
    /**
     * The current search string
     */
    search: {
      type: String,
      default: ""
    }
  },
  emits: [
    /**
     * Fired when the model value is updated
     * @param {any} value The new value
     */
    "update:modelValue",
    /**
     * Fired when the search value is updated
     * @param {string} search The new search value
     */
    "update:search"
  ],
  setup(__props, { expose: __expose, emit: __emit }) {
    const props = __props, emit = __emit, propsFormControl = extractKeysFrom(
      Object.keys(formControlProps).filter((k) => !["modelValue", "placeholder"].includes(k)),
      props
    ), propsDropdown = extractKeysFrom(
      Object.keys(dropdownProps).filter((k) => !["items", "labelKey"].includes(k)),
      props
    ), filteredItems = computed(() => searchValue.value === "" || !props.autoSearch ? props.items : props.items.filter(
      (i) => i.label.toLowerCase().includes(searchValue.value.toLocaleLowerCase())
    )), formControl = ref(), formDropdown = ref(), { bsInstance: bsDropdown } = useBootstrapInstance(
      "Dropdown",
      formControl
    ), modelValue = computed({
      get: () => props.modelValue,
      set: (v) => emit("update:modelValue", v)
    }), modelValueLabel = computed(() => {
      var _a;
      return (_a = modelValue.value) == null ? void 0 : _a[props.labelKey];
    }), searchValue = ref(modelValueLabel.value || props.search), searchValueCached = ref(""), searchValueDisplayed = computed({
      get: () => searchValueCached.value !== "" ? "" : searchValue.value,
      set: (s) => {
        searchValue.value = s, emit("update:search", s);
      }
    });
    onMounted(() => {
      const dropdownToggle = formDropdown.value.$el.querySelector('[data-bs-toggle="dropdown"]');
      dropdownToggle == null || dropdownToggle.addEventListener("shown.bs.dropdown", () => {
        var _a;
        (_a = dropdownToggle.input) == null || _a.focus(), modelValueLabel.value && (searchValueCached.value = modelValueLabel.value), searchValue.value = "", props.search !== "" && emit("update:search", "");
      }), dropdownToggle == null || dropdownToggle.addEventListener("hidden.bs.dropdown", () => {
        var _a;
        (_a = dropdownToggle.input) == null || _a.blur(), modelValue.value ? searchValue.value = modelValueLabel.value : searchValue.value = "", searchValueCached.value = "";
      });
    });
    const showMenu = () => {
      bsDropdown.value && setTimeout(() => bsDropdown.value.show(), 200);
    };
    return watch(
      modelValue,
      (newValue) => {
        newValue ? searchValue.value = newValue[props.labelKey] : searchValue.value = "";
      }
    ), watch(
      () => props.search,
      (s) => searchValue.value = s
    ), __expose({ bsDropdown, formControl }), (_ctx, _cache) => (openBlock(), createBlock(unref(_sfc_main$1), mergeProps({
      ref_key: "formDropdown",
      ref: formDropdown,
      modelValue: modelValue.value,
      "onUpdate:modelValue": _cache[2] || (_cache[2] = ($event) => modelValue.value = $event),
      class: "form-dropdown-search",
      items: filteredItems.value,
      "label-key": __props.labelKey
    }, unref(propsDropdown)), {
      dropdownToggle: withCtx(() => [
        renderSlot(_ctx.$slots, "dropdownToggle", {
          value: modelValue.value,
          search: searchValueDisplayed.value,
          placeholder: searchValueCached.value || __props.placeholder,
          propsFormControl: unref(propsFormControl),
          "onUpdate:search": _cache[0] || (_cache[0] = (s) => searchValueDisplayed.value = s)
        }, () => [
          createVNode(unref(_sfc_main$2), mergeProps({
            ref_key: "formControl",
            ref: formControl,
            modelValue: searchValueDisplayed.value,
            "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => searchValueDisplayed.value = $event),
            class: "form-select",
            "data-bs-toggle": "dropdown",
            placeholder: searchValueCached.value || __props.placeholder
          }, unref(propsFormControl), { onFocus: showMenu }), null, 16, ["modelValue", "placeholder"])
        ])
      ]),
      noOptions: withCtx((slotScope) => [
        renderSlot(_ctx.$slots, "noOptions", normalizeProps(guardReactiveProps(slotScope)))
      ]),
      prepend: withCtx((slotScope) => [
        renderSlot(_ctx.$slots, "prepend", normalizeProps(guardReactiveProps(slotScope)))
      ]),
      items: withCtx((slotScope) => [
        renderSlot(_ctx.$slots, "items", normalizeProps(guardReactiveProps(slotScope)))
      ]),
      item: withCtx((slotScope) => [
        renderSlot(_ctx.$slots, "item", normalizeProps(guardReactiveProps(slotScope)))
      ]),
      append: withCtx((slotScope) => [
        renderSlot(_ctx.$slots, "append", normalizeProps(guardReactiveProps(slotScope)))
      ]),
      _: 3
    }, 16, ["modelValue", "items", "label-key"]));
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=FormDropdownSearch.vue.js.map
