import { defineComponent, computed, openBlock, createElementBlock, normalizeClass, renderSlot, createTextVNode, toDisplayString, createCommentVNode, createVNode, unref, mergeProps, Fragment, renderList } from "vue";
import _sfc_main$1 from "../FormControl/FormControl.vue.js";
import extractKeysFrom from "../../library/extractKeysFrom/index.js";
import { formControlProps } from "../../composables/useFormControl/index.js";
import { idProps } from "../../composables/useId/index.js";
const _hoisted_1 = ["for"], _hoisted_2 = {
  key: 0,
  class: "form-text"
}, _hoisted_3 = {
  key: 3,
  class: "form-text"
}, _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "FormGroup",
  props: {
    /**
     * The description of the form group
     * *Displayed between label and input*
     */
    description: {
      type: String,
      default: void 0
    },
    /**
     * The help text of the form group
     * *Displayed under input*
     */
    helpText: {
      type: String,
      default: void 0
    },
    ...idProps,
    ...formControlProps,
    /**
     * The invalid feedback of the form group
     * *Displayed between input and helpText*
     */
    invalidFeedback: {
      type: [Array, String],
      default: () => []
    },
    /**
     * The label to display
     */
    label: {
      type: String,
      default: void 0
    },
    /**
     * The classes that will be forwarded to the label
     */
    labelClass: {
      type: [String, Array, Object],
      default: void 0
    },
    /**
     * The valid feedback of the form group
     * *Displayed between input and helpText*
     */
    validFeedback: {
      type: [Array, String],
      default: () => []
    }
  },
  emits: [
    /**
     * Fired when the model value is updated
     * @param {any} value The new value
     */
    "update:modelValue"
  ],
  setup(__props, { emit: __emit }) {
    const props = __props, emit = __emit, propsFormControl = extractKeysFrom(Object.keys(formControlProps), props), invalidFeedback = computed(() => [props.invalidFeedback].flat().filter((f) => !!f)), isInvalid = computed(() => !!invalidFeedback.value.length), validFeedback = computed(() => [props.validFeedback].flat().filter((f) => !!f)), isValid = computed(() => !!validFeedback.value.length), validityClass = computed(() => [
      isInvalid.value ? "is-invalid" : void 0,
      isValid.value ? "is-valid" : void 0
    ]);
    return (_ctx, _cache) => (openBlock(), createElementBlock("div", null, [
      _ctx.$slots.label || __props.label || __props.description ? (openBlock(), createElementBlock("label", {
        key: 0,
        class: normalizeClass(["form-label", __props.labelClass]),
        for: _ctx.id
      }, [
        renderSlot(_ctx.$slots, "label", { label: __props.label }, () => [
          createTextVNode(toDisplayString(__props.label), 1)
        ]),
        __props.description ? (openBlock(), createElementBlock("div", _hoisted_2, toDisplayString(__props.description), 1)) : createCommentVNode("", !0)
      ], 10, _hoisted_1)) : createCommentVNode("", !0),
      renderSlot(_ctx.$slots, "default", {
        id: _ctx.id,
        isInvalid: isInvalid.value,
        isValid: isValid.value
      }, () => [
        createVNode(unref(_sfc_main$1), mergeProps(unref(propsFormControl), {
          id: _ctx.id,
          class: validityClass.value,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => emit("update:modelValue", $event))
        }), null, 16, ["id", "class"])
      ]),
      isInvalid.value ? (openBlock(!0), createElementBlock(Fragment, { key: 1 }, renderList(invalidFeedback.value, (feedback) => (openBlock(), createElementBlock("div", {
        key: feedback,
        class: "invalid-feedback"
      }, toDisplayString(feedback), 1))), 128)) : createCommentVNode("", !0),
      isValid.value ? (openBlock(!0), createElementBlock(Fragment, { key: 2 }, renderList(validFeedback.value, (feedback) => (openBlock(), createElementBlock("div", {
        key: feedback,
        class: "valid-feedback"
      }, toDisplayString(feedback), 1))), 128)) : createCommentVNode("", !0),
      __props.helpText ? (openBlock(), createElementBlock("div", _hoisted_3, toDisplayString(__props.helpText), 1)) : createCommentVNode("", !0)
    ]));
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=FormGroup.vue.js.map
