import { defineComponent, ref, computed, watch, openBlock, createElementBlock, createElementVNode, Fragment, renderList, toDisplayString, withDirectives, vModelText } from "vue";
import { idProps } from "../../composables/useId/index.js";
const _hoisted_1 = ["for"], _hoisted_2 = { class: "list-unstyled d-flex align-content-start flex-wrap mb-0" }, _hoisted_3 = { class: "form-pill-text" }, _hoisted_4 = ["onClick"], _hoisted_5 = { class: "form-pill-input-item" }, _hoisted_6 = { class: "form-pill-input-sizer overflow-hidden" }, _hoisted_7 = ["id", "placeholder"], _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "FormPills",
  props: {
    /**
     * Defines if items should be removed when pressing backspace
     */
    editItemOnBackspace: {
      type: Boolean,
      default: !1
    },
    ...idProps,
    /**
     * The maximym amount of items that can be added to the list
     */
    maxItems: {
      type: Number,
      default: 1 / 0
    },
    /**
     * The model value
     */
    modelValue: {
      type: Array,
      default: () => []
    },
    /**
     * The placeholder for the input
     */
    placeholder: {
      type: String,
      default: ""
    },
    /**
     * The separator that checks if an item should be separated from the next one
     */
    separator: {
      type: [String, RegExp],
      // For some reason it does not allow RegExp to be used as default value.
      // eslint-disable-next-line vue/require-valid-default-prop
      default: /[\s\n]+/
    },
    /**
     * The key to press to submit an item
     */
    submitKeys: {
      type: Array,
      default: () => ["Enter"]
    },
    /**
     * The matcher to check if an item is valid
     */
    valueMatcher: {
      type: [String, RegExp],
      // For some reason it does not allow RegExp to be used as default value.
      // eslint-disable-next-line vue/require-valid-default-prop
      default: /^.+$/
    }
  },
  emits: [
    /**
     * Fired when the model value is updated
     * @param {string[]} value The new value
     */
    "update:modelValue"
  ],
  setup(__props, { emit: __emit }) {
    const props = __props, emit = __emit, value = ref(""), clearValue = () => value.value = "", items = computed({
      get: () => props.modelValue,
      set: (v) => emit("update:modelValue", v)
    }), maxItemsReached = computed(() => items.value.length >= props.maxItems), matchItem = (item) => !!item.match(props.valueMatcher), splitItem = (item) => item.split(props.separator), removeItem = (index) => items.value.splice(index, 1), validateValue = (value2) => Array.isArray(value2) ? value2.every(validateValue) : matchItem(value2), addItem = (item) => {
      if (maxItemsReached.value)
        return !1;
      const newItems = splitItem(item).filter(matchItem);
      if (newItems.length === 0)
        return !1;
      const allowedItems = newItems.slice(0, props.maxItems - items.value.length);
      return items.value = items.value.concat(allowedItems), !0;
    };
    watch(value, (v) => {
      const splitItems = splitItem(v);
      splitItems.length > 1 && splitItems.filter(validateValue).length === splitItems.filter((v2) => v2 !== "").length && (addItem(v), clearValue());
    });
    const blur = (event) => {
      const splitItems = splitItem(value.value);
      validateValue(splitItems) && (addItem(value.value), clearValue());
    }, keydown = (event) => {
      if (event.code === "Backspace") {
        if (value.value !== "")
          return;
        const [removedItem] = removeItem(items.value.length - 1);
        props.editItemOnBackspace && removedItem && (value.value = removedItem, event.preventDefault());
        return;
      }
      if (maxItemsReached.value) {
        event.preventDefault();
        return;
      }
      if (props.submitKeys.includes(event.code)) {
        const splitItems = splitItem(value.value);
        validateValue(splitItems) && (addItem(value.value), clearValue()), event.preventDefault();
      }
    }, paste = (event) => {
      event.preventDefault();
      const pasteValue = event.clipboardData.getData("text");
      if (!pasteValue)
        return;
      const newValue = value.value + pasteValue, splitItems = splitItem(newValue);
      validateValue(splitItems) ? (addItem(newValue), clearValue()) : value.value = newValue;
    };
    return (_ctx, _cache) => (openBlock(), createElementBlock("label", {
      class: "form-control",
      for: _ctx.id
    }, [
      createElementVNode("ul", _hoisted_2, [
        (openBlock(!0), createElementBlock(Fragment, null, renderList(__props.modelValue, (item, i) => (openBlock(), createElementBlock("li", {
          key: i,
          class: "form-pill d-inline-flex align-items-center mw-100"
        }, [
          createElementVNode("div", _hoisted_3, toDisplayString(item), 1),
          createElementVNode("div", {
            class: "form-pill-remove",
            onClick: ($event) => removeItem(i)
          }, null, 8, _hoisted_4)
        ]))), 128)),
        createElementVNode("li", _hoisted_5, [
          createElementVNode("div", _hoisted_6, toDisplayString(value.value), 1),
          withDirectives(createElementVNode("input", {
            id: _ctx.id,
            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => value.value = $event),
            class: "form-pill-input w-100",
            type: "text",
            placeholder: items.value.length ? "" : __props.placeholder,
            onBlur: _cache[1] || (_cache[1] = ($event) => blur()),
            onKeydown: _cache[2] || (_cache[2] = ($event) => keydown($event)),
            onPaste: _cache[3] || (_cache[3] = ($event) => paste($event))
          }, null, 40, _hoisted_7), [
            [vModelText, value.value]
          ])
        ])
      ])
    ], 8, _hoisted_1));
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=FormPills.vue.js.map
