import { defineComponent, ref, computed, onBeforeUnmount, openBlock, createElementBlock, createElementVNode, normalizeClass, unref, renderSlot, createTextVNode, toDisplayString, createCommentVNode } from "vue";
import useSize, { sizeProps } from "../../composables/useSize/index.js";
import { idProps } from "../../composables/useId/index.js";
import useBootstrapEmits from "../../composables/useBootstrapEmits/index.js";
import useBootstrapInstance from "../../composables/useBootstrapInstance/index.js";
import useClasses from "../../composables/useClasses/index.js";
const _hoisted_1 = ["id"], _hoisted_2 = { class: "modal-content" }, _hoisted_3 = {
  key: 0,
  class: "modal-title"
}, _hoisted_4 = {
  key: 1,
  class: "btn-close",
  "data-bs-dismiss": "modal",
  type: "button"
}, _hoisted_5 = {
  key: 2,
  class: "modal-footer"
}, modalEvents = ["show", "shown", "hide", "hidden", "hidePrevented"], _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "Modal",
  props: {
    /**
     * The body text of the modal
     */
    body: {
      type: String,
      default: void 0
    },
    /**
     * The classes that will be forwarded to the header
     */
    headerClass: {
      type: [String, Array, Object],
      default: void 0
    },
    /**
     * Defines if the close button should be hidden
     */
    hideCloseBtn: {
      type: Boolean,
      default: !1
    },
    ...idProps,
    /**
     * Defines if the modal should be vertically centered
     */
    modalCentered: {
      type: Boolean,
      default: !1
    },
    /**
     * Defines if the modal should scrollable
     */
    modalScrollable: {
      type: Boolean,
      default: !1
    },
    /**
     * Defines if the `modal-body` class should be omitted
     */
    noBody: {
      type: Boolean,
      default: !1
    },
    ...sizeProps,
    /**
     * The title text of the modal
     */
    title: {
      type: String,
      default: void 0
    }
  },
  setup(__props, { expose: __expose, emit: __emit }) {
    const props = __props, emit = __emit, modal = ref();
    useBootstrapEmits(
      modal,
      modalEvents,
      emit,
      "modal"
    );
    const { bsInstance: bsModal } = useBootstrapInstance(
      "Modal",
      modal
    ), { classes } = useClasses(computed(() => [
      props.modalCentered ? "modal-dialog-centered" : null,
      props.modalScrollable ? "modal-dialog-scrollable" : null,
      props.size ? useSize(props.size, "modal-{0}").sizeClass.value : null
    ]));
    return onBeforeUnmount(() => {
      var _a;
      (_a = bsModal.value) == null || _a.hide();
    }), __expose({ bsModal }), (_ctx, _cache) => (openBlock(), createElementBlock("div", {
      id: _ctx.id,
      ref_key: "modal",
      ref: modal,
      class: "modal"
    }, [
      createElementVNode("div", {
        class: normalizeClass(["modal-dialog", unref(classes)])
      }, [
        createElementVNode("div", _hoisted_2, [
          _ctx.$slots.header || _ctx.$slots.title || __props.title || !__props.hideCloseBtn ? (openBlock(), createElementBlock("div", {
            key: 0,
            class: normalizeClass(["modal-header", __props.headerClass])
          }, [
            renderSlot(_ctx.$slots, "header", {}, () => [
              _ctx.$slots.title || __props.title ? (openBlock(), createElementBlock("h5", _hoisted_3, [
                renderSlot(_ctx.$slots, "title", {}, () => [
                  createTextVNode(toDisplayString(__props.title), 1)
                ])
              ])) : createCommentVNode("", !0),
              __props.hideCloseBtn ? createCommentVNode("", !0) : (openBlock(), createElementBlock("button", _hoisted_4))
            ])
          ], 2)) : createCommentVNode("", !0),
          _ctx.$slots.default || __props.body ? (openBlock(), createElementBlock("div", {
            key: 1,
            class: normalizeClass({ "modal-body": !__props.noBody })
          }, [
            renderSlot(_ctx.$slots, "default", {}, () => [
              createTextVNode(toDisplayString(__props.body), 1)
            ])
          ], 2)) : createCommentVNode("", !0),
          _ctx.$slots.footer ? (openBlock(), createElementBlock("div", _hoisted_5, [
            renderSlot(_ctx.$slots, "footer")
          ])) : createCommentVNode("", !0)
        ])
      ], 2)
    ], 8, _hoisted_1));
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=Modal.vue.js.map
