import { defineComponent, toRef, computed, openBlock, createBlock, resolveDynamicComponent, normalizeClass, unref, withCtx, renderSlot } from "vue";
import { alignProp, gutterProp, justifyProp } from "./type.js";
import useBreakpoints, { breakpointProps } from "../../composables/useBreakpoints/index.js";
import { colProp } from "../../composables/useCol/index.js";
import { tagProps } from "../../composables/useTag/index.js";
import useClasses from "../../composables/useClasses/index.js";
import useStringTemplate from "../../composables/useStringTemplate/index.js";
const propsAlign = breakpointProps(alignProp, "align-{0}"), propsCol = breakpointProps(colProp, "cols-{0}"), propsGutters = breakpointProps(gutterProp, "gutters-{0}"), propsGuttersX = breakpointProps(gutterProp, "gutters-x-{0}"), propsGuttersY = breakpointProps(gutterProp, "gutters-y-{0}"), propsJustify = breakpointProps(justifyProp, "justify-{0}"), _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "Row",
  props: {
    align: alignProp,
    ...propsAlign,
    cols: colProp,
    ...propsCol,
    gutters: gutterProp,
    ...propsGutters,
    guttersX: gutterProp,
    ...propsGuttersX,
    guttersY: gutterProp,
    ...propsGuttersY,
    justify: justifyProp,
    ...propsJustify,
    ...tagProps
  },
  setup(__props) {
    const props = __props, alignProps = {
      sm: toRef(props, "alignSm"),
      md: toRef(props, "alignMd"),
      lg: toRef(props, "alignLg"),
      xl: toRef(props, "alignXl"),
      xxl: toRef(props, "alignXxl")
    }, alignClass = useStringTemplate("align-items-{0}", props.align).templatedString, alignClasses = useBreakpoints(alignProps, "align-items-{0}-{1}").breakpointClasses, colProps = {
      sm: toRef(props, "colsSm"),
      md: toRef(props, "colsMd"),
      lg: toRef(props, "colsLg"),
      xl: toRef(props, "colsXl"),
      xxl: toRef(props, "colsXxl")
    }, colClass = useStringTemplate("row-cols-{0}", props.cols).templatedString, colClasses = useBreakpoints(colProps, "row-cols-{0}-{1}").breakpointClasses, guttersProps = {
      sm: toRef(props, "guttersSm"),
      md: toRef(props, "guttersMd"),
      lg: toRef(props, "guttersLg"),
      xl: toRef(props, "guttersXl"),
      xxl: toRef(props, "guttersXxl")
    }, guttersClass = useStringTemplate("g-{0}", props.gutters).templatedString, guttersClasses = useBreakpoints(guttersProps, "g-{0}-{1}").breakpointClasses, guttersXProps = {
      sm: toRef(props, "guttersXSm"),
      md: toRef(props, "guttersXMd"),
      lg: toRef(props, "guttersXLg"),
      xl: toRef(props, "guttersXXl"),
      xxl: toRef(props, "guttersXXxl")
    }, guttersXClass = useStringTemplate("gx-{0}", props.guttersX).templatedString, guttersXClasses = useBreakpoints(guttersXProps, "gx-{0}-{1}").breakpointClasses, guttersYProps = {
      sm: toRef(props, "guttersYSm"),
      md: toRef(props, "guttersYMd"),
      lg: toRef(props, "guttersYLg"),
      xl: toRef(props, "guttersYXl"),
      xxl: toRef(props, "guttersYXxl")
    }, guttersYClass = useStringTemplate("gy-{0}", props.guttersY).templatedString, guttersYClasses = useBreakpoints(guttersYProps, "gy-{0}-{1}").breakpointClasses, justifyProps = {
      sm: toRef(props, "justifySm"),
      md: toRef(props, "justifyMd"),
      lg: toRef(props, "justifyLg"),
      xl: toRef(props, "justifyXl"),
      xxl: toRef(props, "justifyXxl")
    }, justifyClass = useStringTemplate("justify-content-{0}", props.justify).templatedString, justifyClasses = useBreakpoints(justifyProps, "justify-content-{0}-{1}").breakpointClasses, { classes } = useClasses(computed(() => [
      alignClass.value,
      ...alignClasses.value,
      colClass.value,
      ...colClasses.value,
      guttersClass.value,
      ...guttersClasses.value,
      guttersXClass.value,
      ...guttersXClasses.value,
      guttersYClass.value,
      ...guttersYClasses.value,
      justifyClass.value,
      ...justifyClasses.value
    ]));
    return (_ctx, _cache) => (openBlock(), createBlock(resolveDynamicComponent(_ctx.tag), {
      class: normalizeClass(["row", unref(classes)])
    }, {
      default: withCtx(() => [
        renderSlot(_ctx.$slots, "default")
      ]),
      _: 3
    }, 8, ["class"]));
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=Row.vue.js.map
