import { defineComponent, ref, computed, openBlock, createElementBlock, normalizeClass, unref, createElementVNode, Fragment, renderList, renderSlot, createTextVNode, toDisplayString, createCommentVNode } from "vue";
import useClasses from "../../composables/useClasses/index.js";
import "../../composables/useFormControl/index.js";
import "uuid";
const _hoisted_1 = { key: 0 }, _hoisted_2 = ["onClick"], _hoisted_3 = ["onClick", "onMouseenter"], _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "Table",
  props: {
    /**
     * The fields of the table
     */
    fields: {
      type: Array,
      required: !1,
      default: void 0
    },
    /**
     * The items that are shown in the table
     */
    items: {
      type: Array,
      default: () => []
    },
    /**
     * Defines if multiple items can be sorted at once
     */
    multiSort: {
      type: Boolean,
      default: !1
    },
    /**
     * Defines if the `table-hover` class should be used
     */
    hover: {
      type: Boolean,
      default: !1
    },
    /**
     * Defines if the `table-click` class should be used
     */
    // $attrs doesn't return emitted events, so
    // we have to catch it as a prop
    // eslint-disable-next-line vue/prop-name-casing
    "onClick:row": {
      type: Function,
      default: void 0
    },
    /**
     * The classes that will be forwarded to the tbody tr
     */
    tbodyTrClass: {
      type: [String, Array, Object, Function],
      default: void 0
    },
    /**
     * The classes that will be forwarded to the tbody tr
     */
    theadTrClass: {
      type: [String, Array, Object],
      default: void 0
    }
  },
  emits: ["click:row", "hover:row", "sort"],
  setup(__props, { emit: __emit }) {
    const props = __props, emit = __emit, sorted = ref(
      (props.fields || []).filter((f) => f.sortable && f.sort).reduce((obj, item) => Object.assign(obj, { [item.key]: item.sort }), {})
    ), headers = computed(() => {
      if (props.fields)
        return props.fields;
      const first = props.items.find((i) => i !== void 0);
      return first ? Object.keys(first).map((f) => ({ key: f })) : [];
    }), sort = (field) => {
      if (!field.sortable)
        return;
      const key = field.key, sort2 = sorted.value[key];
      props.multiSort ? sort2 === "asc" ? sorted.value[key] = "desc" : sort2 === "desc" ? delete sorted.value[key] : sorted.value[key] = "asc" : sorted.value = {
        [key]: sort2 === "asc" ? "desc" : "asc"
      }, emit("sort", sorted.value);
    }, { classes } = useClasses(computed(() => [
      props.hover && "table-hover",
      props["onClick:row"] && "table-click"
    ]));
    return (_ctx, _cache) => (openBlock(), createElementBlock("table", {
      class: normalizeClass(["table", unref(classes)])
    }, [
      headers.value.length ? (openBlock(), createElementBlock("thead", _hoisted_1, [
        createElementVNode("tr", {
          class: normalizeClass(__props.theadTrClass)
        }, [
          (openBlock(!0), createElementBlock(Fragment, null, renderList(headers.value, (header) => renderSlot(_ctx.$slots, `header-${header.key}`, {
            key: `header-${header.key}`,
            header
          }, () => [
            (openBlock(), createElementBlock("th", {
              key: header.key,
              class: normalizeClass({
                "table-heading-sortable": header.sortable,
                "table-heading-sortable-asc": sorted.value[header.key] === "asc",
                "table-heading-sortable-desc": sorted.value[header.key] === "desc"
              }),
              onClick: ($event) => sort(header)
            }, [
              renderSlot(_ctx.$slots, `header-${header.key}-content`, { header }, () => [
                createTextVNode(toDisplayString(header.label || header.key), 1)
              ])
            ], 10, _hoisted_2))
          ])), 128))
        ], 2)
      ])) : createCommentVNode("", !0),
      createElementVNode("tbody", null, [
        renderSlot(_ctx.$slots, "top-row", { headers: headers.value }),
        __props.items.length ? (openBlock(!0), createElementBlock(Fragment, { key: 1 }, renderList(__props.items, (item, index) => renderSlot(_ctx.$slots, "row", {
          key: `item-${index}`,
          item,
          index
        }, () => [
          createElementVNode("tr", {
            class: normalizeClass(typeof __props.tbodyTrClass == "function" ? __props.tbodyTrClass(item) : __props.tbodyTrClass),
            onClick: ($event) => _ctx.$emit("click:row", item),
            onMouseenter: ($event) => _ctx.$emit("hover:row", item, $event)
          }, [
            (openBlock(!0), createElementBlock(Fragment, null, renderList(headers.value, (header) => renderSlot(_ctx.$slots, header.key, {
              key: header.key,
              field: header,
              item,
              index,
              value: item[header.key]
            }, () => [
              (openBlock(), createElementBlock("td", {
                key: `item-${index}-${header}`
              }, [
                renderSlot(_ctx.$slots, `${header.key}-content`, {
                  field: header,
                  item,
                  index,
                  value: item[header.key]
                }, () => [
                  createTextVNode(toDisplayString(item[header.key]), 1)
                ])
              ]))
            ])), 128))
          ], 42, _hoisted_3)
        ])), 128)) : renderSlot(_ctx.$slots, "no-items", {
          key: 0,
          headers: headers.value
        }),
        renderSlot(_ctx.$slots, "bottom-row", { headers: headers.value })
      ])
    ], 2));
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=Table.vue.js.map
