import { defineComponent, ref, computed, onBeforeUnmount, openBlock, createBlock, resolveDynamicComponent, withCtx, renderSlot } from "vue";
import { tooltipFallbackPlacementProps, tooltipPlacementProps } from "../../composables/useTooltipPlacement/index.js";
import { triggerProps } from "../../composables/useTrigger/index.js";
import useBootstrapEmits from "../../composables/useBootstrapEmits/index.js";
import useBootstrapInstance from "../../composables/useBootstrapInstance/index.js";
const tooltipEvents = ["show", "shown", "hide", "hidden", "inserted"], _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "Tooltip",
  props: {
    /**
     * Overflow constraint boundary of the tooltip
     */
    boundary: {
      type: [String, Object],
      default: "clippingParents"
    },
    /**
     * Appends the tooltip to the given element
     */
    container: {
      type: [String, Object, Boolean],
      default: !1
    },
    /**
     * The classes that will be forwarded to the tooltip
     */
    customClass: {
      type: [String, Array, Object],
      default: ""
    },
    /**
     * Delay showing and hiding the tooltip in milliseconds
     */
    delay: {
      type: [Number, Object],
      default: 0
    },
    /**
     * Defines if HTML is allowed in the tooltip
     */
    html: {
      type: Boolean,
      default: !1
    },
    /**
     * The x, y offset of the tooltip
     */
    offset: {
      type: [String, Array],
      default: () => [0, 0]
    },
    /**
     * Change Bootstrap's default Popper config
     */
    popperConfig: {
      type: [Object, Function],
      default: () => ({})
    },
    /**
     * The tag to be used for the list group item
     */
    tag: {
      type: String,
      default: "div"
    },
    /**
     * The text to display in the tooltip
     */
    title: {
      type: [String, Number],
      default: ""
    },
    ...tooltipFallbackPlacementProps,
    ...tooltipPlacementProps,
    ...triggerProps
  },
  setup(__props, { expose: __expose, emit: __emit }) {
    const props = __props, tooltip = ref(), emit = __emit, tooltipClass = computed(() => typeof props.customClass == "string" ? props.customClass : Array.isArray(props.customClass) ? props.customClass.join(" ") : Object.keys(props.customClass).filter((key) => !!props.customClass[key]).join(" ")), tooltipTriggers = computed(() => Array.isArray(props.trigger) ? props.trigger.join(" ") : props.trigger);
    useBootstrapEmits(
      tooltip,
      tooltipEvents,
      emit,
      "tooltip"
    );
    const { bsInstance: bsTooltip } = useBootstrapInstance(
      "Tooltip",
      tooltip,
      {
        ...props,
        customClass: tooltipClass.value,
        trigger: tooltipTriggers.value
      }
    );
    return onBeforeUnmount(() => {
      var _a;
      (_a = bsTooltip.value) == null || _a.dispose();
    }), __expose({ bsTooltip }), (_ctx, _cache) => (openBlock(), createBlock(resolveDynamicComponent(__props.tag), {
      ref_key: "tooltip",
      ref: tooltip
    }, {
      default: withCtx(() => [
        renderSlot(_ctx.$slots, "default")
      ]),
      _: 3
    }, 512));
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=Tooltip.vue.js.map
